==> okta-sdk-api-21.0.0-sources.jar: com/okta/sdk/resource/model/EventHookLinks.java <==
package com.okta.sdk.resource.model;

import java.util.Objects;
import java.util.Arrays;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonCreator;
import com.fasterxml.jackson.annotation.JsonTypeName;
import com.fasterxml.jackson.annotation.JsonValue;
import com.okta.sdk.resource.model.HrefObject;
import com.okta.sdk.resource.model.HrefObjectSelfLink;
import java.io.Serializable;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import com.fasterxml.jackson.annotation.JsonTypeName;
import io.swagger.annotations.ApiModelProperty;
import io.swagger.annotations.ApiModel;

/**
 * EventHookLinks
 */
@JsonPropertyOrder({ EventHookLinks.JSON_PROPERTY_SELF, EventHookLinks.JSON_PROPERTY_DEACTIVATE,
        EventHookLinks.JSON_PROPERTY_VERIFY })
@JsonTypeName("EventHook__links")
@jakarta.annotation.Generated(value = "org.openapitools.codegen.languages.JavaClientCodegen", date = "2025-02-24T22:29:38.763116-06:00[America/Chicago]", comments = "Generator version: 7.11.0")
public class EventHookLinks implements Serializable {

    private static final long serialVersionUID = 1L;

    public static final String JSON_PROPERTY_SELF = "self";
    private HrefObjectSelfLink self;

    public static final String JSON_PROPERTY_DEACTIVATE = "deactivate";
    private HrefObject deactivate;

    public static final String JSON_PROPERTY_VERIFY = "verify";
    private HrefObject verify;

    public EventHookLinks() {
    }

    public EventHookLinks self(HrefObjectSelfLink self) {

        this.self = self;
        return this;
    }

    /**
     * Get self
     *
     * @return self
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "")
    @JsonProperty(JSON_PROPERTY_SELF)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public HrefObjectSelfLink getSelf() {
        return self;
    }

    @JsonProperty(JSON_PROPERTY_SELF)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setSelf(HrefObjectSelfLink self) {
        this.self = self;
    }

    public EventHookLinks deactivate(HrefObject deactivate) {

        this.deactivate = deactivate;
        return this;
    }

    /**
     * Get deactivate
     *
     * @return deactivate
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "")
    @JsonProperty(JSON_PROPERTY_DEACTIVATE)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public HrefObject getDeactivate() {
        return deactivate;
    }

    @JsonProperty(JSON_PROPERTY_DEACTIVATE)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setDeactivate(HrefObject deactivate) {
        this.deactivate = deactivate;
    }

    public EventHookLinks verify(HrefObject verify) {

        this.verify = verify;
        return this;
    }

    /**
     * Get verify
     *
     * @return verify
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "")
    @JsonProperty(JSON_PROPERTY_VERIFY)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public HrefObject getVerify() {
        return verify;
    }

    @JsonProperty(JSON_PROPERTY_VERIFY)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setVerify(HrefObject verify) {
        this.verify = verify;
    }

    @Override
    public boolean equals(Object o) {
        if (this == o) {
            return true;
        }
        if (o == null || getClass() != o.getClass()) {
            return false;
        }
        EventHookLinks eventHookLinks = (EventHookLinks) o;
        return Objects.equals(this.self, eventHookLinks.self)
                && Objects.equals(this.deactivate, eventHookLinks.deactivate)
                && Objects.equals(this.verify, eventHookLinks.verify);
        // ;
    }

    @Override
    public int hashCode() {
        return Objects.hash(self, deactivate, verify);
    }

    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append("class EventHookLinks {\n");
        sb.append("    self: ").append(toIndentedString(self)).append("\n");
        sb.append("    deactivate: ").append(toIndentedString(deactivate)).append("\n");
        sb.append("    verify: ").append(toIndentedString(verify)).append("\n");
        sb.append("}");
        return sb.toString();
    }

    /**
     * Convert the given object to string with each line indented by 4 spaces (except the first line).
     */
    private String toIndentedString(Object o) {
        if (o == null) {
            return "null";
        }
        return o.toString().replace("\n", "\n    ");
    }

}

==> okta-sdk-api-24.0.0-sources.jar: com/okta/sdk/resource/model/EventHookLinks.java <==
package com.okta.sdk.resource.model;

import java.util.Objects;
import java.util.Arrays;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonCreator;
import com.fasterxml.jackson.annotation.JsonTypeName;
import com.fasterxml.jackson.annotation.JsonValue;
import com.okta.sdk.resource.model.HrefObject;
import com.okta.sdk.resource.model.HrefObjectSelfLink;
import java.io.Serializable;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import com.fasterxml.jackson.annotation.JsonTypeName;
import io.swagger.annotations.ApiModelProperty;
import io.swagger.annotations.ApiModel;

/**
 * EventHookLinks
 */
@JsonPropertyOrder({ EventHookLinks.JSON_PROPERTY_SELF, EventHookLinks.JSON_PROPERTY_DEACTIVATE,
        EventHookLinks.JSON_PROPERTY_VERIFY })
@JsonTypeName("EventHook__links")
@jakarta.annotation.Generated(value = "org.openapitools.codegen.languages.JavaClientCodegen", date = "2025-07-28T10:14:57.946459+05:30[Asia/Kolkata]", comments = "Generator version: 7.11.0")
public class EventHookLinks implements Serializable {

    private static final long serialVersionUID = 1L;

    public static final String JSON_PROPERTY_SELF = "self";
    private HrefObjectSelfLink self;

    public static final String JSON_PROPERTY_DEACTIVATE = "deactivate";
    private HrefObject deactivate;

    public static final String JSON_PROPERTY_VERIFY = "verify";
    private HrefObject verify;

    public EventHookLinks() {
    }

    public EventHookLinks self(HrefObjectSelfLink self) {

        this.self = self;
        return this;
    }

    /**
     * Get self
     *
     * @return self
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "")
    @JsonProperty(JSON_PROPERTY_SELF)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public HrefObjectSelfLink getSelf() {
        return self;
    }

    @JsonProperty(JSON_PROPERTY_SELF)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setSelf(HrefObjectSelfLink self) {
        this.self = self;
    }

    public EventHookLinks deactivate(HrefObject deactivate) {

        this.deactivate = deactivate;
        return this;
    }

    /**
     * Get deactivate
     *
     * @return deactivate
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "")
    @JsonProperty(JSON_PROPERTY_DEACTIVATE)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public HrefObject getDeactivate() {
        return deactivate;
    }

    @JsonProperty(JSON_PROPERTY_DEACTIVATE)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setDeactivate(HrefObject deactivate) {
        this.deactivate = deactivate;
    }

    public EventHookLinks verify(HrefObject verify) {

        this.verify = verify;
        return this;
    }

    /**
     * Get verify
     *
     * @return verify
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "")
    @JsonProperty(JSON_PROPERTY_VERIFY)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public HrefObject getVerify() {
        return verify;
    }

    @JsonProperty(JSON_PROPERTY_VERIFY)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setVerify(HrefObject verify) {
        this.verify = verify;
    }

    @Override
    public boolean equals(Object o) {
        if (this == o) {
            return true;
        }
        if (o == null || getClass() != o.getClass()) {
            return false;
        }
        EventHookLinks eventHookLinks = (EventHookLinks) o;
        return Objects.equals(this.self, eventHookLinks.self)
                && Objects.equals(this.deactivate, eventHookLinks.deactivate)
                && Objects.equals(this.verify, eventHookLinks.verify);
        // ;
    }

    @Override
    public int hashCode() {
        return Objects.hash(self, deactivate, verify);
    }

    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append("class EventHookLinks {\n");
        sb.append("    self: ").append(toIndentedString(self)).append("\n");
        sb.append("    deactivate: ").append(toIndentedString(deactivate)).append("\n");
        sb.append("    verify: ").append(toIndentedString(verify)).append("\n");
        sb.append("}");
        return sb.toString();
    }

    /**
     * Convert the given object to string with each line indented by 4 spaces (except the first line).
     */
    private String toIndentedString(Object o) {
        if (o == null) {
            return "null";
        }
        return o.toString().replace("\n", "\n    ");
    }

}
